@@ -50,8 +50,8 @@ class VncView: public RemoteView
     Q_OBJECT
 
 public:
-    explicit VncView(QWidget *parent = 0, const QUrl &url = QUrl(), KConfigGroup configGroup = KConfigGroup());
-    ~VncView();
+    explicit VncView(QWidget *parent = nullptr, const QUrl &url = QUrl(), KConfigGroup configGroup = KConfigGroup());
+    ~VncView() override;
 
     QSize framebufferSize() override;
     QSize sizeHint() const override;
